package com.zfire.jiasm.syncdata.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.gree.GreeLogic;
import com.zfire.jiasm.syncdata.helper.GreeFileResponseHelper;
import com.zfire.jiasm.syncdata.helper.GreeFileSaveHelper;
import com.zfire.jiasm.syncdata.http.PostObjectSample;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.response.ResultData;
import com.zfire.jiasm.syncdata.service.PublicService;
import com.zfire.jiasm.syncdata.service.UploadWorkeCertificateService;
import com.zfire.jiasm.syncdata.utils.oss.OSSUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.*;


@Slf4j
@Service
public class UploadWorkeCertificateServiceImpl implements UploadWorkeCertificateService {
    @Resource
    OSSUtil ossUtil;
    @Resource
    GreeLogic greeLogic;
    @Resource
    WorkerCertService workerCertService;
    @Resource
    WorkerBrandAccountService workerBrandAccountService;
    @Resource
    BaseService baseService;
    @Resource
    PublicService publicService;
    @Resource
    InsureWorkerRecordService insureWorkerRecordService;
    @Resource
    InsureWorkerCommercialService insureWorkerCommercialService;
    @Resource
    InsureWorkerCommercialFileService insureWorkerCommercialFileService;
    @Resource
    WorkerMrbxService workerMrbxService;
    @Resource
    WebsitWorkerService websitWorkerService;



    @Override
    public void procesUploadWorkeCert() {
        List<WorkerCert> recs = new ArrayList<>();
        List<WorkerBrandAccount> workerWdnos = new ArrayList<>();
        String fileo ="";
        String filet ="";
        String fid3 = "";
        Integer count = 0;

        // 提取品牌信息 用于多品牌数据同步目前仅格力，可以先不用做
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        // 获取待同步到格力总部师傅的证件信息
        recs = getWorkerUploads();

        for (WorkerCert item:recs){
            fileo ="";
            filet ="";
            count = 0;

            try{
                //  查看师傅是否已选中品牌商网点(这里只提取选中格力品牌商的师傅数据)
                workerWdnos = workerBrandAccountService.lambdaQuery()
                        .eq(WorkerBrandAccount::getWorkerId, item.getWorkerId())
                        .eq(WorkerBrandAccount::getBrandWorkerStatus,"ON")
                        .eq(WorkerBrandAccount::getDel,0)
                        .eq(WorkerBrandAccount::getGroupCompanyId, brand.getBrandId()).list();

                // 未选择品牌商
                if (workerWdnos.size()<1){
                    updateWorkCertificateerror(item,"师傅未选择格力品牌商信息");
                    continue;
                }

                //  判断师傅入驻的商户网点
                count = getCount(workerWdnos, count);
                if (count.equals(workerWdnos.size())){
                    updateWorkCertificateerror(item,"师傅未入驻品牌商网点");
                    continue;
                }

                // 生成图片 System.getProperty("java.io.tmpdir")
                if (StringUtils.isNotEmpty(item.getFileUrl()) && (StringUtils.isEmpty(item.getOutFileUrl()))){
                    fileo = publicService.path(item.getFileUrl());
                    File nFile = publicService.createf(fileo);
                    // 下载文件生成新文件 fid1
                    baseService.saveToFile(ossUtil.getUrlWw(item.getFileUrl()),nFile);

                }
                if (StringUtils.isNotEmpty(item.getFileUrl2()) && (StringUtils.isEmpty(item.getOutFileUrl2()))){
                    filet = publicService.path(item.getFileUrl2());
                    File nFile = publicService.createf(filet);
                    // 下载文件生成新文件 fid2
                    baseService.saveToFile(ossUtil.getUrlWw(item.getFileUrl2()),nFile);
                }

                // 上传图片 按网点上传
                for (WorkerBrandAccount wdno: workerWdnos){
                    if (StringUtils.isEmpty(wdno.getBrandWebsitId())){
                        continue;
                    }

                    uploadFileexc(fileo, filet,wdno.getBrandWebsitId(),item);
                    delfilet(fid3);
                    // 保险数据同步 保险证不在证件表中
                    // fid3 = uploadInsureCert(wdno);
                    fid3 = uploadInsureBx(wdno);
                }

                // 文件清除
                delfile(fileo, filet, fid3);
            } catch (Exception ex) {
                ex.printStackTrace();
                log.info("同步师傅证件失败：【" + item.getId() + "】");
                String msg = "同步师傅证件失败：";
                if (com.baomidou.mybatisplus.core.toolkit.StringUtils.isNotEmpty(ex.getMessage())){
                    msg = msg + ex.getMessage();
                }
                updateWorkCertificateerror(item,msg);
            }
        }
    }


    private void delfile(String fileo,String filet,String file3) {
        if (StringUtils.isNotEmpty(fileo)){
            new File(fileo).delete();
        }
        if (StringUtils.isNotEmpty(filet)){
            new File(filet).delete();
        }
        if (StringUtils.isNotEmpty(file3)){
            new File(file3).delete();
        }
    }

    private void delfiletow(String fid1, String fid2) {
        if (StringUtils.isNotEmpty(fid1)){
            new File(fid1).delete();
        }
        if (StringUtils.isNotEmpty(fid2)){
            new File(fid2).delete();
        }
    }

    private void delfilet(String file3) {
        if (StringUtils.isNotEmpty(file3)){
            new File(file3).delete();
        }
    }

    /**
     * 初始化保险数据(可以不买保险)
     * out_insure_cert 总部保证凭证 为空时
     *    insure_cert为空  初始化生成
     *               不为空正常生成
     */
    private String uploadInsureCert(WorkerBrandAccount wdno) throws Exception {
        String fileo ="";
        String fid1 = "";
        InsureWorkerRecord wk = insureWorkerRecordService.lambdaQuery()
                .eq(InsureWorkerRecord::getWebsitWorkerId, wdno.getWebsitWorkerId())
                .eq(InsureWorkerRecord::getStatus, "ON")
                .ne(InsureWorkerRecord::getVoucher, "").last("limit 1").one();
        if (StringUtils.isEmpty(wk.getOutVoucher())){
            // 生成图片
            if (StringUtils.isEmpty(wk.getVoucher())){
                fid1 = publicService.path("bx.jpg");
                File nFile = publicService.createf(fid1);
                baseService.initFile(nFile);
            } else {
                fid1 = publicService.path(wk.getVoucher());
                File nFile = publicService.createf(fid1);
                baseService.saveToFile(ossUtil.getUrlWw(wk.getVoucher()),nFile);
            }
            fileo = fid1;
            uploadInitFileexc(fileo, fid1, wdno.getBrandWebsitId(),wk);
        }
        return fid1;
    }


    private String uploadInsureBxBak(WorkerBrandAccount wdno) throws Exception {
        String fileo ="";
        String fid1 = "";

        InsureWorkerCommercial iwc = insureWorkerCommercialService.lambdaQuery()
                .eq(InsureWorkerCommercial::getWorkerId, wdno.getWorkerId())
                .eq(InsureWorkerCommercial::getWebsitId, wdno.getWebsitId())
                .last("limit 1").one();
        if (iwc != null){
            InsureWorkerCommercialFile iwcf = insureWorkerCommercialFileService.lambdaQuery()
                    .eq(InsureWorkerCommercialFile::getInsureWorkerCommercialId,iwc.getId())
                    .last("limit 1").one();
            if (iwcf !=null){
                if (StringUtils.isNotEmpty(iwcf.getOutZjlj())){
                    // 已上传就不需要再上传
                    return fid1;
                }
                if (StringUtils.isNotEmpty(iwcf.getFileUrl())){
                    // 上传
                    fid1 = publicService.path(iwcf.getFileUrl());
                    File nFile = publicService.createf(fid1);
                    baseService.saveToFile(ossUtil.getUrlWw(iwcf.getFileUrl()),nFile);
                    fileo = fid1;
                    uploadInitFile(fileo, fid1, wdno.getBrandWebsitId(),iwcf);
                    return fid1;
                }
            }
        }
        // 查家用保险
        InsureWorkerRecord wk = insureWorkerRecordService.lambdaQuery()
                .eq(InsureWorkerRecord::getWorkerId, wdno.getWorkerId())
                .eq(InsureWorkerRecord::getWebsitId, wdno.getWebsitId())
                .last("limit 1").one();
        if (wk !=null){
            if (StringUtils.isNotEmpty(wk.getOutVoucher())){
                // 已上传就不需要再上传
                return fid1;
            }
            if (StringUtils.isNotEmpty(wk.getVoucher())){
                // 上传
                fid1 = publicService.path(wk.getVoucher());
                File nFile = publicService.createf(fid1);
                baseService.saveToFile(ossUtil.getUrlWw(wk.getVoucher()),nFile);
                fileo = fid1;
                uploadInitFileexc(fileo, fid1, wdno.getBrandWebsitId(),wk);
                return fid1;
            }
        }


        // 加上getWebsitId条件找不到时，去掉getWebsitId条件
        InsureWorkerCommercial iwcc = insureWorkerCommercialService.lambdaQuery()
                .eq(InsureWorkerCommercial::getWorkerId, wdno.getWorkerId())
                // .eq(InsureWorkerCommercial::getWebsitId, wdno.getWebsitId())
                .orderByDesc(InsureWorkerCommercial::getEndTime)
                .last("limit 1").one();
        if (iwcc != null){
            InsureWorkerCommercialFile iwcf = insureWorkerCommercialFileService.lambdaQuery()
                    .eq(InsureWorkerCommercialFile::getInsureWorkerCommercialId,iwcc.getId())
                    .last("limit 1").one();
            if (iwcf !=null){
                if (StringUtils.isNotEmpty(iwcf.getOutZjlj())){
                    // 已上传就不需要再上传
                    return fid1;
                }
                if (StringUtils.isNotEmpty(iwcf.getFileUrl())){
                    // 上传
                    fid1 = publicService.path(iwcf.getFileUrl());
                    File nFile = publicService.createf(fid1);
                    baseService.saveToFile(ossUtil.getUrlWw(iwcf.getFileUrl()),nFile);
                    fileo = fid1;
                    uploadInitFile(fileo, fid1, wdno.getBrandWebsitId(),iwcf);
                    return fid1;
                }
            }
        }
        // 查家用保险
        InsureWorkerRecord wkk = insureWorkerRecordService.lambdaQuery()
                .eq(InsureWorkerRecord::getWorkerId, wdno.getWorkerId())
                // .eq(InsureWorkerRecord::getWebsitId, wdno.getWebsitId())
                .orderByDesc(InsureWorkerRecord::getEndTime)
                .last("limit 1").one();
        if (wkk !=null){
            if (StringUtils.isNotEmpty(wkk.getOutVoucher())){
                // 已上传就不需要再上传
                return fid1;
            }
            if (StringUtils.isNotEmpty(wkk.getVoucher())){
                // 上传
                fid1 = publicService.path(wkk.getVoucher());
                File nFile = publicService.createf(fid1);
                baseService.saveToFile(ossUtil.getUrlWw(wkk.getVoucher()),nFile);
                fileo = fid1;
                uploadInitFileexc(fileo, fid1, wdno.getBrandWebsitId(),wkk);
                return fid1;
            }
        }




        // 师傅必买保险，所以不会不存在
        return fid1;

        /*// 增加一个已上传过的表判断
        WorkerMrbx mbx = workerMrbxService.lambdaQuery()
                .eq(WorkerMrbx::getWorkerId, wdno.getWorkerId())
                .eq(WorkerMrbx::getWebsitId, wdno.getWebsitId())
                .isNotNull(WorkerMrbx::getOutZjlj)
                .last("limit 1").one();
        if (mbx != null){
            // 存在上传过的默认就不再上传 无论传的是哪一个师傅的 统一使用一个默认的
            return fid1;
        }

        // 都没有时上传 默认
        WorkerMrbx wmrbx = new WorkerMrbx();
        wmrbx.setId(IdWorker.getIdStr());
        wmrbx.setWorkerId(wdno.getWorkerId());
        wmrbx.setWebsitId(wdno.getWebsitId());
        fid1 = publicService.path("bx.jpg");
        baseService.initFile(fid1);
        fileo = fid1;
        uploadInitMRFileexc(fileo, fid1, wdno.getBrandWebsitId(),wmrbx);

        return fid1;*/
    }

    private String uploadInsureBx(WorkerBrandAccount wdno) throws Exception {
        String fileo ="";
        String fid1 = "";
        String outInsureCert = "";

        WebsitWorker iwcf = websitWorkerService.lambdaQuery()
                .eq(WebsitWorker::getWorkerId, wdno.getWorkerId())
                .eq(WebsitWorker::getWebsitId, wdno.getWebsitId())
                .last("limit 1").one();
        if (iwcf != null){
            if (StringUtils.isNotEmpty(iwcf.getOutInsureCert())){
                // 已上传就不需要再上传
                return fid1;
            }
            if (StringUtils.isNotEmpty(iwcf.getInsureFiles())){
                // 上传
                if (iwcf.getInsureFiles().contains(",")){
                    int num=0;

                    List<String> result = Arrays.asList(iwcf.getInsureFiles().split(","));
                    for (String p:result){
                        fid1 = publicService.path(p);
                        File nFile = publicService.createf(fid1);
                        baseService.saveToFile(ossUtil.getUrlWw(iwcf.getFileUrl()),nFile);
                        fileo = fid1;
                        uploadInitFileBx(fileo, fid1, wdno.getBrandWebsitId());
                        if (StringUtils.isEmpty(fid1)){
                            return fid1;
                        }

                        if (num == 0){
                            outInsureCert = fid1;
                        } else {
                            outInsureCert= outInsureCert +","+fid1;
                        }
                        new File(fid1).delete();
                        num = num +1 ;
                    }
                } else {
                    fid1 = publicService.path(iwcf.getInsureFiles());
                    File nFile = publicService.createf(fid1);
                    baseService.saveToFile(ossUtil.getUrlWw(iwcf.getFileUrl()),nFile);
                    fileo = fid1;
                    uploadInitFileBx(fileo, fid1, wdno.getBrandWebsitId());
                    if (StringUtils.isEmpty(fid1)){
                        return fid1;
                    }
                }
                iwcf.setOutInsureCert(outInsureCert);
                iwcf.updateById();
            }
        }
        // 师傅必买保险，所以不会不存在
        return fid1;
    }

    private Boolean uploadFileexc(String fileo, String filet, String wdno,WorkerCert item) throws Exception {
        Boolean uploadfile = Boolean.TRUE;
        Boolean onlyone = Boolean.FALSE;
        String msg = "";

        if (StringUtils.isEmpty(wdno)){
            return Boolean.TRUE;
        }

        // 先上传第一个图片
        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fileo);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());

                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String> req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(fileo, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);
                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        if (StringUtils.isEmpty(filet)){
                            // 说明只有第一个图片
                            onlyone = Boolean.TRUE;
                        }
                        updateWorkCertificatesave(item,responses.getData().getId(),1,uploadfile,onlyone);
                    } else {
                        // 失败
                        uploadfile = Boolean.FALSE;
                        msg = "保存证件正面文件到格力总部失败";
                        if (StringUtils.isNotEmpty(responses.getMsg())){
                            msg = msg + responses.getMsg();
                        }
                        updateWorkCertificateerror(item,msg);
                    }
                } else {
                    updateWorkCertificateerror(item,"上传图片到OSS失败");
                }
            } else {
                updateWorkCertificateerror(item,"获取签名信息失败");
                return Boolean.TRUE;
            }
        }

        if (StringUtils.isNotEmpty(filet)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+filet);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(filet, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(filet, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        updateWorkCertificatesave(item,responses.getData().getId(),2,uploadfile,onlyone);
                    } else {
                        // 失败
                        msg = "保存证件正面文件到格力总部失败";
                        if (StringUtils.isNotEmpty(responses.getMsg())){
                            msg = msg + responses.getMsg();
                        }
                        updateWorkCertificateerror(item,msg);
                        return Boolean.TRUE;
                    }
                } else {
                    updateWorkCertificateerror(item,"上传图片到OSS失败");
                    return Boolean.TRUE;
                }
            } else {
                updateWorkCertificateerror(item,"获取签名信息失败");
                return Boolean.TRUE;
            }
        }
        return Boolean.FALSE;
    }


    private Boolean uploadInitFileexc(String fileo, String fid1,String wdno,InsureWorkerRecord wk) throws Exception {

        if (StringUtils.isEmpty(wdno)){
            return Boolean.TRUE;
        }

        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid1);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(fid1, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        wk.setOutVoucher(responses.getData().getId());
                        insureWorkerRecordService.updateById(wk);
                    } else {
                        // 失败
                        log.info("保存保险证件文件到格力总部失败");
                    }
                } else {
                    log.info("保险证件上传图片到OSS失败");
                }
            } else {
                log.info("获取签名信息失败");
                return Boolean.TRUE;
            }
        }

        return Boolean.FALSE;
    }


    private Boolean uploadInitMRFileexc(String fileo, String fid1,String wdno,WorkerMrbx wk) throws Exception {

        if (StringUtils.isEmpty(wdno)){
            return Boolean.TRUE;
        }

        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid1);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(fid1, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        wk.setOutZjlj(responses.getData().getId());
                        wk.setSyncTime(new Date());
                        workerMrbxService.save(wk);
                    } else {
                        // 失败
                        log.info("保存保险证件文件到格力总部失败");
                    }
                } else {
                    log.info("保险证件上传图片到OSS失败");
                }
            } else {
                log.info("获取签名信息失败");
                return Boolean.TRUE;
            }
        }

        return Boolean.FALSE;
    }

    private Boolean uploadInitFile(String fileo, String fid1,String wdno,InsureWorkerCommercialFile wk) throws Exception {
        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid1);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(fid1, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        wk.setOutZjlj(responses.getData().getId());
                        wk.setOutZjljProcess(1);
                        wk.updateById();
                    } else {
                        // 失败
                        log.info("保存保险证件文件到格力总部失败");
                    }
                } else {
                    log.info("保险证件上传图片到OSS失败");
                }
            } else {
                log.info("获取签名信息失败");
                return Boolean.TRUE;
            }
        }

        return Boolean.FALSE;
    }


    private String uploadInitFileBx(String fileo, String fid1,String wdno) throws Exception {
        String fileId="";
        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid1);
                // 2:文件上传
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对象
                    getSaveFileInfo(fid1, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        fileId = responses.getData().getId();
                    } else {
                        // 失败
                        log.info("保存保险证件文件到格力总部失败");
                    }
                } else {
                    log.info("保险证件上传图片到OSS失败");
                }
            } else {
                log.info("获取签名信息失败");
            }
        }

        return fileId;
    }

    private Integer getCount(List<WorkerBrandAccount> workerWdnos, Integer count) {
        for (WorkerBrandAccount w: workerWdnos){
            if (StringUtils.isEmpty(w.getBrandWebsitId())){
                count++;
            }
        }
        return count;
    }

    private void updateWorkCertificateerror(WorkerCert item, String msg) {
        WorkerCert v = new WorkerCert();
        v.setId(item.getId());
        v.setOutSyncTime(new Date());
        v.setOutSyncErrorMsg(msg);
        v.setOutSyncTimes(item.getOutSyncTimes() +1);
        if (msg.length()>250){
            v.setOutSyncErrorMsg(msg.substring(0,250));
        }
        workerCertService.updateById(v);
    }


    private void updateWorkCertificatesave(WorkerCert i, String file, Integer flag,
                                           Boolean bool, Boolean onlyOne) {
        WorkerCert v = new WorkerCert();
        v.setId(i.getId());
        if (flag ==1){
            v.setOutFileUrl(file);
            if (onlyOne){
                v.setOutSyncStatus(1);
            }
        } else {
            v.setOutFileUrl2(file);
            if (bool){
                v.setOutSyncStatus(1);
            }
        }
        v.setOutSyncTime(new Date());
        workerCertService.updateById(v);
    }

    private void getSaveFileInfo(String id1, ResultData resultData, Map<String, String> req) {
        req.put("bizAppId","flydiy-auto-sit-default-front-greeshmerge");
        req.put("bizTable","default");
        req.put("bizType","default");
        req.put("accessType","auth");
        req.put("url", resultData.getExtData().getDir());
        req.put("name", id1);
    }


    /**
     * 该表只进行增加数据
     *     相同类型数据只取最大ID
     * @return
     */
    private List<WorkerCert> getWorkerUploads() {
        // 同步标志-synStatus(0:待同步;1:已同步;99:同步失败)
        return workerCertService.lambdaQuery()
                .in(WorkerCert::getOutSyncStatus,0,99)
                .lt(WorkerCert::getOutSyncTimes,10)
                .list();
    }
}
